@@ -1467,6 +1467,7 @@ nautilus_burn_make_iso_from_drive (const char                  *filename,
 	}
 
 	g_ptr_array_free (argv, TRUE);
+	argv = NULL;
 	g_free (stdout_data);
 
 	if (has_audio) {
@@ -1544,7 +1545,10 @@ nautilus_burn_make_iso_from_drive (const char                  *filename,
 	g_free (outfile_arg);
 	g_free (tocfile_arg);
 	g_free (device_arg);
-	g_ptr_array_free (argv, TRUE);
+	if (argv) {
+		g_ptr_array_free (argv, TRUE);
+		argv = NULL;
+	}
 
 	if (mkisofs_output.result == NAUTILUS_BURN_RECORDER_RESULT_ERROR) {
 		if (!mkisofs_output.error)
